import
{ 
	select, 
  csv, 
  scaleLinear, 
  extent,
  axisLeft,
  axisBottom,
  TickFormat,
  scaleOrdinal
} from 'd3';

import dropdownMenu from './dropdownMenu';

dropdownMenu(select('body'), 
{
  options: ['A' , 'B' , 'C']           
});

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data =>
{ 
  
  const xValue = d => d['Kommunal skattesats'];
  const yValue = d => d['Medelvärde förvärvsinkomst'];
  const zValue = d => d.Medelålder;
  const cirlceRadius = 8;
  const xAxisLable = "Kommunal skattesats";
  const yAxisLable = "Medelvärde förvärvsinkomst";
  const margin = {top: 45,right: 20, bottom: 55, left: 120 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  
  const xScale = scaleLinear()
  .domain(extent(data, xValue))
  .range([28.5, innerWidth])
  .nice();
  
  const yScale = scaleLinear()
  .domain(extent(data, yValue))
  .range([innerHeight,0])
  .nice();
  
  const zScale = scaleLinear()
    .domain(extent(data, zValue))
    .range([1, 15]);
  
  const g = svg.append('g')
  .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
  .tickSize(-innerHeight)
  .tickPadding(5);
  
  const yAxis = axisLeft(yScale)
  .tickSize(-innerWidth)
  .tickPadding(10);
  
  const yAxisG = g.append('g')
  .call(yAxis);
  yAxisG.selectAll('.domain')
  .remove();
  
  const xAxisG = g.append('g')
  .call(xAxis)
  .attr('transform', `translate(0,${innerHeight})`);
  xAxisG.select('.domain')
  .remove();
  
  yAxisG.append('text')
  .attr('class', 'axis-lable')
  .attr('y', -90)
  .attr('x', -innerHeight / 5.2)
  .attr('fill', 'black' )
  .attr('transform', `rotate(-90)`)
  .attr('text-achor', 'middle')
  .text(yAxisLable);
  
  
  xAxisG.append('text')
  .attr('class', 'axis-lable')
  .attr('y', 45)
  .attr('x', innerWidth / 2)
  .attr('fill', 'black' )
  .text(xAxisLable);
  
  
  g.selectAll('circle').data(data)
  .enter().append('circle')
  .attr('cy', d => yScale(yValue(d)))
  .attr('cx',  d => xScale(xValue(d)))
  .attr('r', d => zScale(zValue(d)));
  
};

csv('data.csv').then(data => 
{
  data.forEach(d => 
  {
    d['Medelvärde förvärvsinkomst'] = +d['Medelvärde förvärvsinkomst'];
    d['Kommunal skattesats'] = +d['Kommunal skattesats'];
  	d['Antal högskolestuderande'] = +d['Antal högskolestuderande'];
    d.Medelålder = +d.Medelålder;
  	d['Antal lägenheter i flerbostadshus'] = +d['Antal lägenheter i flerbostadshus'];
    d['Antal inflyttade'] = +d['Antal inflyttade'];
    d['Antal utflyttade'] = +d['Antal utflyttade'];
    d.Folkmängd = +d.Folkmängd;
  });
	render(d